if not SimpleTankFrames then return end
local addon = SimpleTankFrames

local frame = CreateFrame("Frame", nil, InterfaceOptionsFramePanelContainer)
frame.name = "SimpleTankFrames"
frame:Hide()

local function newCheckbox(label, onClick)
	local check = CreateFrame("CheckButton", "SimpleTankFrameCheck" .. label, frame, "InterfaceOptionsCheckButtonTemplate")
	check:SetScript("OnClick", function(self)
		PlaySound(self:GetChecked() and "igMainMenuOptionCheckBoxOn" or "igMainMenuOptionCheckBoxOff")
		onClick(self, self:GetChecked() and true or false)
	end)
	_G[check:GetName() .. "Text"]:SetText(label)
	return check
end

local checkboxFunc = function(self, value) addon.db[self.key] = value end

frame:SetScript("OnShow", function(frame)
	local title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText("SimpleTankFrames")

	local subtitle = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	subtitle:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
	subtitle:SetPoint("RIGHT", -32, 0)
	subtitle:SetHeight(32)
	subtitle:SetJustifyH("LEFT")
	subtitle:SetJustifyV("TOP")
	subtitle:SetText("oRA2-style main tank frames populated by the sorted tank list from oRA3. |cffff4411Note that NONE of these settings apply until you reload your interface or relog.|r")

	local lock = newCheckbox("Lock", checkboxFunc)
	lock.key = "lock"
	lock:SetChecked(addon.db.lock)
	lock:SetPoint("TOPLEFT", subtitle, "BOTTOMLEFT", -2, -8)

	local percent = newCheckbox("Hitpoints", checkboxFunc)
	percent.key = "showHp"
	percent:SetChecked(addon.db.showHp)
	percent:SetPoint("TOPLEFT", lock, "BOTTOMLEFT", 0, -8)

	local highlight = newCheckbox("Target highlight", checkboxFunc)
	highlight.key = "highlight"
	highlight:SetChecked(addon.db.highlight)
	highlight:SetPoint("TOPLEFT", subtitle, "BOTTOMRIGHT", -160, -8)

	local tot = newCheckbox("Target of target", checkboxFunc)
	tot.key = "tot"
	tot:SetChecked(addon.db.tot)
	tot:SetPoint("TOPLEFT", highlight, "BOTTOMLEFT", 0, -8)

	local growup = newCheckbox("Grow upwards", checkboxFunc)
	growup.key = "growup"
	growup:SetChecked(addon.db.growup)
	growup:SetPoint("TOPLEFT", percent, "BOTTOMLEFT", 0, -8)

	local media = LibStub and LibStub("LibSharedMedia-3.0", true)
	local texture = nil
	if media then
		texture = frame:CreateFontString(nil, "OVERLAY", "GameFontNormal")
		texture:SetPoint("TOPLEFT", growup, "BOTTOMLEFT", 8, -24)
		texture:SetJustifyH("LEFT")
		texture:SetHeight(18)
		texture:SetText("Texture")
		local dropdown = CreateFrame("Frame", "SimpleTankFrameTextureDropdown", frame, "UIDropDownMenuTemplate")
		dropdown:SetPoint("TOPLEFT", texture, "TOPRIGHT", 16, 3)
		local function itemOnClick(self)
			local selected = self.value
			local actualTexture = media:Fetch("statusbar", selected)
			addon.db.bar = actualTexture
			UIDropDownMenu_SetSelectedValue(dropdown, selected)
		end
		UIDropDownMenu_Initialize(dropdown, function()
			local info = UIDropDownMenu_CreateInfo()
			for name, tex in pairs(media:HashTable("statusbar")) do
				info.text = name
				info.value = name
				info.func = itemOnClick
				info.checked = tex == addon.db.bar
				UIDropDownMenu_AddButton(info)
			end
		end)
		UIDropDownMenu_SetSelectedValue(dropdown, addon.db.bar)
		UIDropDownMenu_SetWidth(dropdown, 160)
		UIDropDownMenu_JustifyText(dropdown, "LEFT")
	end

	local sliderLabel = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	sliderLabel:SetJustifyH("LEFT")
	sliderLabel:SetText("Scale")
	sliderLabel:SetPoint("TOPLEFT", texture or growup, "BOTTOMLEFT", 8, -24)

	local sliderValue = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	sliderValue:SetJustifyH("LEFT")
	sliderValue:SetText(addon.db.scale)

	local slider = CreateFrame("Slider", nil, frame)
	slider:SetHeight(17)
	slider:SetWidth(144)
	slider:SetOrientation("HORIZONTAL")
	slider:SetThumbTexture("Interface\\Buttons\\UI-SliderBar-Button-Horizontal")
	slider:SetBackdrop({
		bgFile = "Interface\\Buttons\\UI-SliderBar-Background",
		edgeFile = "Interface\\Buttons\\UI-SliderBar-Border",
		edgeSize = 8, tile = true, tileSize = 8,
		insets = {left = 3, right = 3, top = 6, bottom = 6}
	})
	slider:SetMinMaxValues(0.1, 1)
	slider:SetValue(addon.db.scale)
	slider:SetValueStep(0.05)
	slider:SetScript("OnValueChanged", function(self, value)
		addon.db.scale = value
		sliderValue:SetText(value)
	end)
	slider:SetPoint("LEFT", sliderLabel, "RIGHT", 36, 0)
	sliderValue:SetPoint("LEFT", slider, "RIGHT", 8, 0)

	local alphaLabel = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	alphaLabel:SetJustifyH("LEFT")
	alphaLabel:SetText("Alpha")
	alphaLabel:SetPoint("TOPLEFT", sliderLabel, "BOTTOMLEFT", 0, -24)

	local alphaValue = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	alphaValue:SetJustifyH("LEFT")
	alphaValue:SetText(addon.db.alpha)

	local alpha = CreateFrame("Slider", nil, frame)
	alpha:SetHeight(17)
	alpha:SetWidth(144)
	alpha:SetOrientation("HORIZONTAL")
	alpha:SetThumbTexture("Interface\\Buttons\\UI-SliderBar-Button-Horizontal")
	alpha:SetBackdrop(slider:GetBackdrop())
	alpha:SetMinMaxValues(0, 1)
	alpha:SetValue(addon.db.alpha)
	alpha:SetValueStep(0.1)
	alpha:SetScript("OnValueChanged", function(self, value)
		addon.db.alpha = value
		alphaValue:SetText(value)
	end)
	alpha:SetPoint("LEFT", alphaLabel, "RIGHT", 36, 0)
	alphaValue:SetPoint("LEFT", alpha, "RIGHT", 8, 0)

	frame:SetScript("OnShow", nil)
end)
InterfaceOptions_AddCategory(frame)

